aboutsummaryrefslogtreecommitdiffstats
path: root/include/qpdf/QPDFAnnotationObjectHelper.hh
diff options
context:
space:
mode:
Diffstat (limited to 'include/qpdf/QPDFAnnotationObjectHelper.hh')
-rw-r--r--include/qpdf/QPDFAnnotationObjectHelper.hh21
1 files changed, 6 insertions, 15 deletions
diff --git a/include/qpdf/QPDFAnnotationObjectHelper.hh b/include/qpdf/QPDFAnnotationObjectHelper.hh
index 76ff0eac..47242499 100644
--- a/include/qpdf/QPDFAnnotationObjectHelper.hh
+++ b/include/qpdf/QPDFAnnotationObjectHelper.hh
@@ -72,23 +72,14 @@ class QPDFAnnotationObjectHelper: public QPDFObjectHelper
QPDFObjectHandle getAppearanceStream(std::string const& which,
std::string const& state = "");
- // Return a matrix that transforms from the annotation's
- // appearance stream's coordinates to the page's coordinates. This
- // method also honors the annotation's NoRotate flag if set. The
- // matrix is returned as a string representing the six floating
- // point numbers to be passed to a cm operator. Returns the empty
- // string if it is unable to compute the matrix for any reason.
- // The value "rotate" should be set to the page's /Rotate value or
- // 0 if none.
- QPDF_DLL
- std::string getAnnotationAppearanceMatrix(int rotate);
-
// Generate text suitable for addition to the containing page's
// content stream that replaces this annotation's appearance
// stream. The value "rotate" should be set to the page's /Rotate
// value or 0 if none.
QPDF_DLL
- std::string getPageContentForAppearance(int rotate);
+ std::string getPageContentForAppearance(
+ std::string const& name, int rotate);
private:
class Members
@@ -72,23 +72,14 @@ class QPDFAnnotationObjectHelper: public QPDFObjectHelper
// Generate text suitable for addition to the containing page's
- // content stream that replaces this annotation's appearance
- // stream. The value "rotate" should be set to the page's /Rotate
- // value or 0 if none.
+ // content stream that draws this annotation's appearance stream
+ // as a form XObject. The value "name" is the resource name that
+ // will be used to refer to the form xobject. The value "rotate"
+ // should be set to the page's /Rotate value or 0 if none.
QPDF_DLL